==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerDefaultActionRedirectArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property host Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
 * @property path Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
 * @property port Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
 * @property protocol Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
 * @property query Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
 * @property statusCode HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
 * The following arguments are optional:
 */
public data class ListenerDefaultActionRedirectArgs(
    public val host: Output<String>? = null,
    public val path: Output<String>? = null,
    public val port: Output<String>? = null,
    public val protocol: Output<String>? = null,
    public val query: Output<String>? = null,
    public val statusCode: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs =
        com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs.builder()
            .host(host?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .protocol(protocol?.applyValue({ args0 -> args0 }))
            .query(query?.applyValue({ args0 -> args0 }))
            .statusCode(statusCode.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerDefaultActionRedirectArgs].
 */
@PulumiTagMarker
public class ListenerDefaultActionRedirectArgsBuilder internal constructor() {
    private var host: Output<String>? = null

    private var path: Output<String>? = null

    private var port: Output<String>? = null

    private var protocol: Output<String>? = null

    private var query: Output<String>? = null

    private var statusCode: Output<String>? = null

    /**
     * @param value Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
     */
    @JvmName("rloheosufqdsdhkx")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
     */
    @JvmName("slmfygdcnejpprmx")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
     */
    @JvmName("nnuwyimokihihtee")
    public suspend fun port(`value`: Output<String>) {
        this.port = value
    }

    /**
     * @param value Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
     */
    @JvmName("axmrivqlblrcdtkc")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
     */
    @JvmName("mwjoxktcxliejiin")
    public suspend fun query(`value`: Output<String>) {
        this.query = value
    }

    /**
     * @param value HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
     * The following arguments are optional:
     */
    @JvmName("sxochuowveojfhmg")
    public suspend fun statusCode(`value`: Output<String>) {
        this.statusCode = value
    }

    /**
     * @param value Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
     */
    @JvmName("eedrmuaxvkumrwdk")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
     */
    @JvmName("mjsqjyvnavajflky")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
     */
    @JvmName("rvhgalrkqcnpmbni")
    public suspend fun port(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
     */
    @JvmName("jyforngkhfbjwyms")
    public suspend fun protocol(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
     */
    @JvmName("umrwaeyecqyrdplv")
    public suspend fun query(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.query = mapped
    }

    /**
     * @param value HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
     * The following arguments are optional:
     */
    @JvmName("vnowyhfvdorvpuqm")
    public suspend fun statusCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCode = mapped
    }

    internal fun build(): ListenerDefaultActionRedirectArgs = ListenerDefaultActionRedirectArgs(
        host = host,
        path = path,
        port = port,
        protocol = protocol,
        query = query,
        statusCode = statusCode ?: throw PulumiNullFieldException("statusCode"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerDefaultActionRedirectArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property host Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
 * @property path Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
 * @property port Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
 * @property protocol Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
 * @property query Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
 * @property statusCode HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
 * The following arguments are optional:
 */
public data class ListenerDefaultActionRedirectArgs(
    public val host: Output<String>? = null,
    public val path: Output<String>? = null,
    public val port: Output<String>? = null,
    public val protocol: Output<String>? = null,
    public val query: Output<String>? = null,
    public val statusCode: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs =
        com.pulumi.aws.alb.inputs.ListenerDefaultActionRedirectArgs.builder()
            .host(host?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .protocol(protocol?.applyValue({ args0 -> args0 }))
            .query(query?.applyValue({ args0 -> args0 }))
            .statusCode(statusCode.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerDefaultActionRedirectArgs].
 */
@PulumiTagMarker
public class ListenerDefaultActionRedirectArgsBuilder internal constructor() {
    private var host: Output<String>? = null

    private var path: Output<String>? = null

    private var port: Output<String>? = null

    private var protocol: Output<String>? = null

    private var query: Output<String>? = null

    private var statusCode: Output<String>? = null

    /**
     * @param value Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
     */
    @JvmName("comowegtjayrrvwg")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
     */
    @JvmName("qgaspojlbmnfmutr")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
     */
    @JvmName("qaxounfsaexjviqv")
    public suspend fun port(`value`: Output<String>) {
        this.port = value
    }

    /**
     * @param value Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
     */
    @JvmName("svqvtfehncfjimst")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
     */
    @JvmName("omoqxflagssykeju")
    public suspend fun query(`value`: Output<String>) {
        this.query = value
    }

    /**
     * @param value HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
     * The following arguments are optional:
     */
    @JvmName("mrwtgcufovlgtkgw")
    public suspend fun statusCode(`value`: Output<String>) {
        this.statusCode = value
    }

    /**
     * @param value Hostname. This component is not percent-encoded. The hostname can contain `#{host}`. Defaults to `#{host}`.
     */
    @JvmName("cruyvxqrqowobwli")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}. Defaults to `/#{path}`.
     */
    @JvmName("ibkfuixuvdxllnoq")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Port. Specify a value from `1` to `65535` or `#{port}`. Defaults to `#{port}`.
     */
    @JvmName("grpgudyaonlmxerm")
    public suspend fun port(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol. Valid values are `HTTP`, `HTTPS`, or `#{protocol}`. Defaults to `#{protocol}`.
     */
    @JvmName("vvqlfxvwmtremmws")
    public suspend fun protocol(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?". Defaults to `#{query}`.
     */
    @JvmName("jamcnejnvgkopxgs")
    public suspend fun query(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.query = mapped
    }

    /**
     * @param value HTTP redirect code. The redirect is either permanent (`HTTP_301`) or temporary (`HTTP_302`).
     * The following arguments are optional:
     */
    @JvmName("uxpijjyndhctkaqg")
    public suspend fun statusCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCode = mapped
    }

    internal fun build(): ListenerDefaultActionRedirectArgs = ListenerDefaultActionRedirectArgs(
        host = host,
        path = path,
        port = port,
        protocol = protocol,
        query = query,
        statusCode = statusCode ?: throw PulumiNullFieldException("statusCode"),
    )
}
